@@ -6,7 +6,7 @@ import ast
 import copy
 import os
 import re
-import subprocess
+import subprocess  # noqa: S404
 from collections import UserDict
 from typing import TYPE_CHECKING, Literal
 
@@ -16,7 +16,7 @@ from ansible_compat.constants import ANSIBLE_MIN_VERSION
 from ansible_compat.errors import InvalidPrerequisiteError, MissingAnsibleError
 from ansible_compat.ports import cache
 
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: no cover
     from pathlib import Path
 
 
@@ -59,8 +59,8 @@ def ansible_version(version: str = "") -> Version:
     if version:
         return Version(version)
 
-    proc = subprocess.run(
-        ["ansible", "--version"],  # noqa: S603
+    proc = subprocess.run(  # noqa: S603
+        ["ansible", "--version"],
         text=True,
         check=False,
         capture_output=True,
@@ -290,7 +290,7 @@ class AnsibleConfig(UserDict[str, object]):  # pylint: disable=too-many-ancestor
     galaxy_role_skeleton_ignore: list[str] = ["^.git$", "^.*/.git_keep$"]
     galaxy_server: str = "https://galaxy.ansible.com"
     galaxy_server_list: str | None = None
-    galaxy_token_path: str = "~/.ansible/galaxy_token"
+    galaxy_token_path: str = "~/.ansible/galaxy_token"  # noqa: S105
     host_key_checking: bool = True
     host_pattern_mismatch: Literal["warning", "error", "ignore"] = "warning"
     inject_facts_as_vars: bool = True
@@ -413,8 +413,8 @@ class AnsibleConfig(UserDict[str, object]):  # pylint: disable=too-many-ancestor
                 env = os.environ.copy()
                 # Avoid possible ANSI garbage
                 env["ANSIBLE_FORCE_COLOR"] = "0"
-                config_dump = subprocess.check_output(
-                    ["ansible-config", "dump"],  # noqa: S603
+                config_dump = subprocess.check_output(  # noqa: S603
+                    ["ansible-config", "dump"],
                     universal_newlines=True,
                     env=env,
                 )
@@ -446,9 +446,9 @@ class AnsibleConfig(UserDict[str, object]):  # pylint: disable=too-many-ancestor
 
     def __getattribute__(self, attr_name: str) -> object:
         """Allow access of config options as attributes."""
-        _dict = super().__dict__  # pylint: disable=no-member
-        if attr_name in _dict:
-            return _dict[attr_name]
+        parent_dict = super().__dict__  # pylint: disable=no-member
+        if attr_name in parent_dict:
+            return parent_dict[attr_name]
 
         data = super().__getattribute__("data")
         if attr_name == "data":  # pragma: no cover
@@ -476,8 +476,8 @@ class AnsibleConfig(UserDict[str, object]):  # pylint: disable=too-many-ancestor
 
 
 __all__ = [
-    "ansible_collections_path",
-    "parse_ansible_version",
-    "ansible_version",
     "AnsibleConfig",
+    "ansible_collections_path",
+    "ansible_version",
+    "parse_ansible_version",
 ]
